@@ -1,10 +1,11 @@
 # Claudio Perez
-__version__ = "0.1.0"
+__version__ = "0.1.5"
 
 from pathlib import Path
 
 from . import csmip, nga, eqsig, basic_formats, opensees
 
+
 FILE_TYPES = {}
 # Avoid repeated dot lookup
 _register_file_type = FILE_TYPES.update
@@ -19,6 +20,7 @@ DEFAULT_TYPES = {
     ".AT2": "nga.at2",
     ".zip": "csmip.zip",
     ".v2": "csmip.v2",
+    ".V2": "csmip.v2",
     ".json": "json",
 }
 
@@ -27,7 +29,7 @@ def read(read_file, input_format=None, **kwds):
     """
     Generic ground motion reader
     """
-    if input_format:
+    if input_format is not None:
         typ = input_format
     else:
         try:
